@@ -29,22 +29,14 @@ class IndicatorsManager;
 #include <QWidget>
 #include <QEvent>
 
+#include "screeninfo.h"
+
 struct Unity2dPanelPrivate;
 class Unity2dPanel : public QWidget
 {
     Q_OBJECT
-    /**
-     * The amount of pixels the panel is moved from its edge. Useful for
-     * animations.
-     */
-    Q_PROPERTY(int delta READ delta WRITE setDelta)
-    /**
-     * Whether the delta property is being set by an external client. Setting
-     * this property to true stops any animation of the delta property triggered
-       by slideIn() or slideOut().
-     */
-    Q_PROPERTY(int manualSliding READ manualSliding WRITE setManualSliding NOTIFY manualSlidingChanged)
     Q_PROPERTY(bool useStrut READ useStrut WRITE setUseStrut NOTIFY useStrutChanged)
+    Q_ENUMS(Edge)
 
 public:
     enum Edge {
@@ -54,12 +46,16 @@ public:
 
     static const QEvent::Type SHOW_FIRST_MENU_EVENT = QEvent::User;
 
-    Unity2dPanel(bool requiresTransparency = false, QWidget* parent = 0);
+    Unity2dPanel(bool requiresTransparency = false, int screen = -1,
+                 ScreenInfo::Corner corner = ScreenInfo::InvalidCorner, QWidget* parent = 0);
     ~Unity2dPanel();
 
     void setEdge(Edge);
     Edge edge() const;
 
+    void setScreen(int);
+    int screen() const;
+
     void addWidget(QWidget*);
 
     void addSpacer();
@@ -73,25 +69,15 @@ public:
     bool useStrut() const;
     void setUseStrut(bool);
 
-    int delta() const;
-    void setDelta(int);
-
     int panelSize() const;
 
-    bool manualSliding() const;
-    void setManualSliding(bool);
-
-public Q_SLOTS:
-    void slideIn();
-    void slideOut();
+    QString id() const;
 
 Q_SIGNALS:
-    void manualSlidingChanged(bool);
     void useStrutChanged(bool);
 
 protected:
     virtual void showEvent(QShowEvent*);
-    virtual void resizeEvent(QResizeEvent*);
     virtual void paintEvent(QPaintEvent*);
 
 private Q_SLOTS:
