@@ -46,7 +46,6 @@
 
 using namespace Unity2d;
 
-static const char* PANEL_DCONF_SCHEMA = "com.canonical.Unity2d.Panel";
 static const char* PANEL_DCONF_PROPERTY_APPLETS = "applets";
 static const char* PANEL_PLUGINS_DEV_DIR_ENV = "UNITY2D_PANEL_PLUGINS_PATH";
 
@@ -78,7 +77,7 @@ static QHash<QString, PanelAppletProviderInterface*> loadPlugins()
     filters << "*.so";
     pluginDir.setNameFilters(filters);
 
-    Q_FOREACH(QString fileEntry, pluginDir.entryList()) {
+    Q_FOREACH(const QString& fileEntry, pluginDir.entryList()) {
         QString pluginFilePath = pluginDir.absoluteFilePath(fileEntry);
         qDebug() << "Loading panel plugin:" << pluginFilePath;
 
@@ -103,11 +102,11 @@ static QHash<QString, PanelAppletProviderInterface*> loadPlugins()
 
 QStringList PanelManager::loadPanelConfiguration() const
 {
-    QVariant appletsConfig = m_conf.property(PANEL_DCONF_PROPERTY_APPLETS);
+    QVariant appletsConfig = panel2dConfiguration().property(PANEL_DCONF_PROPERTY_APPLETS);
     if (!appletsConfig.isValid()) {
         qWarning() << "Missing or invalid panel applets configuration in dconf. Please check"
                    << "the property" << PANEL_DCONF_PROPERTY_APPLETS
-                   << "in schema" << PANEL_DCONF_SCHEMA;
+                   << "in schema" << PANEL2D_DCONF_SCHEMA;
         return QStringList();
     }
 
@@ -116,21 +115,37 @@ QStringList PanelManager::loadPanelConfiguration() const
 
 PanelManager::PanelManager(QObject* parent)
 : QObject(parent)
-, m_conf(PANEL_DCONF_SCHEMA)
 {
+    Unity2dPanel* panel;
     QDesktopWidget* desktop = QApplication::desktop();
+
+    QPoint p;
+    if (QApplication::isRightToLeft()) {
+        p = QPoint(desktop->width() - 1, 0);
+    }
+    int leftmost = desktop->screenNumber(p);
+
+    panel = instantiatePanel(leftmost);
+    m_panels.append(panel);
+    panel->show();
+    panel->move(desktop->screenGeometry(leftmost).topLeft());
+
     for(int i = 0; i < desktop->screenCount(); ++i) {
-        Unity2dPanel* panel = instantiatePanel(i);
+        if (i == leftmost) {
+            continue;
+        }
+        panel = instantiatePanel(i);
         m_panels.append(panel);
         panel->show();
         panel->move(desktop->screenGeometry(i).topLeft());
     }
-    connect(desktop, SIGNAL(screenCountChanged(int)), SLOT(onScreenCountChanged(int)));
+    connect(desktop, SIGNAL(screenCountChanged(int)), SLOT(updateScreenLayout(int)));
+    connect(desktop, SIGNAL(resized(int)), SLOT(onScreenResized(int)));
 
     /* A F10 keypress opens the first menu of the visible application or of the first
        indicator on the panel */
-    Hotkey* F10 = HotkeyMonitor::instance().getHotkeyFor(Qt::Key_F10, Qt::NoModifier);
-    connect(F10, SIGNAL(released()), SLOT(onF10Pressed()));
+    Hotkey* F10 = HotkeyMonitor::instance().getHotkeyFor(Qt::Key_F10, Qt::AltModifier);
+    connect(F10, SIGNAL(released()), SLOT(onAltF10Pressed()));
 }
 
 PanelManager::~PanelManager()
@@ -140,10 +155,11 @@ PanelManager::~PanelManager()
 
 Unity2dPanel* PanelManager::instantiatePanel(int screen)
 {
-    Unity2dPanel* panel = new Unity2dPanel;
+    Unity2dPanel* panel = new Unity2dPanel(false, screen);
     panel->setAccessibleName("Top Panel");
     panel->setEdge(Unity2dPanel::TopEdge);
     panel->setFixedHeight(24);
+    panel->setAttribute(Qt::WA_TranslucentBackground, true);
 
     QPoint p;
     if (QApplication::isRightToLeft()) {
@@ -183,7 +199,25 @@ Unity2dPanel* PanelManager::instantiatePanel(int screen)
 }
 
 void
-PanelManager::onScreenCountChanged(int newCount)
+PanelManager::onScreenResized(int screen)
+{
+    QPoint p;
+    QDesktopWidget* desktop = QApplication::desktop();
+    if (QApplication::isRightToLeft()) {
+        p = QPoint(desktop->width() - 1, 0);
+    }
+    int leftmost = desktop->screenNumber(p);
+
+    /*  We only care about the leftmost screen being resized,
+        because there is no screenLayoutChanged signal, we're
+        abusing it here so that we update the panels  */
+    if (screen == leftmost) {
+        updateScreenLayout(desktop->screenCount());
+    }
+}
+
+void
+PanelManager::updateScreenLayout(int newCount)
 {
     if (newCount > 0) {
         QDesktopWidget* desktop = QApplication::desktop();
@@ -199,7 +233,7 @@ PanelManager::onScreenCountChanged(int newCount)
             m_panels.append(panel);
         }
         panel->show();
-        panel->move(desktop->screenGeometry(leftmost).topLeft());
+        panel->setScreen(leftmost);
 
         /* Update the position of other existing panels, and instantiate new
            panels as needed. */
@@ -215,7 +249,7 @@ PanelManager::onScreenCountChanged(int newCount)
                 m_panels.append(panel);
             }
             panel->show();
-            panel->move(desktop->screenGeometry(screen).topLeft());
+            panel->setScreen(screen);
             ++i;
         }
     }
@@ -225,7 +259,7 @@ PanelManager::onScreenCountChanged(int newCount)
     }
 }
 
-void PanelManager::onF10Pressed()
+void PanelManager::onAltF10Pressed()
 {
     QDesktopWidget* desktop = QApplication::desktop();
     int screen = desktop->screenNumber(QCursor::pos());
