@@ -34,7 +34,7 @@ class WindowHelper : public QObject
 {
 Q_OBJECT
 public:
-    WindowHelper(QObject* parent);
+    WindowHelper(int screen, QObject* parent);
     ~WindowHelper();
 
     void setXid(uint);
@@ -46,6 +46,8 @@ public Q_SLOTS:
     void close();
     void minimize();
     void unmaximize();
+    void maximize();
+    void toggleMaximize();
     void drag(const QPoint& pos);
 
 private Q_SLOTS:
